<xsl:stylesheet xmlns:xsl='http://www.w3.org/1999/XSL/Transform' xmlns:saxon="http://icl.com/saxon" extension-element-prefixes="saxon" version="1.0">  

<xsl:import href="../../../share/XSLT/bottomLinks.xsl"/>
<xsl:import href="examplesStylesheet.xslt"/>
<xsl:import href="../../../share/XSLT/descriptionTop.xslt"/>
<xsl:import href="../../../share/XSLT/indexMenu.xslt"/>

<xsl:variable name="tab">&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</xsl:variable>

<xsl:variable name='maxShortItems' select="20"/>
<xsl:variable name="letters">abcdefghijklmnopqrstuvwxyz</xsl:variable>

<xsl:key name="parent" match="xhtmlReference/element" use="child"/>
<xsl:key name="attribute" match="xhtmlReference/element/attribute" use="@name"/>
<xsl:key name="otherDTD" match="dtd" use="@name"/>

<xsl:param name="dtdName"/>
<xsl:param name="basePath"/>
<xsl:param name="pwd"/>

<xsl:variable name="zvonItemid" select="document('../Data/frontpage.xml')/frontPage/@idref"/>

<xsl:variable name="menu">
  <groups xmlns="">
    <group id="short" href="./shorta.html" title="Elements"/>
    <group id="long"  href="./long.html"  title="Elements - all"/>
    <group id="attrs" href="./attrs.html" title="Attributes"/>
  </groups>
</xsl:variable>


<xsl:template match="/">
  <xsl:apply-templates select="//example" mode="printXHTML"/>
  <html>
    <head>
      <title>Zvon XHTML reference</title>
    </head>
    <frameset cols="250,*">
      <frame name="mainIndex" src="Strict/shorta.html"/>
      <frame name="mainWindow" src="introduction.html"/>
    </frameset>
  </html>
  <!--
  <xsl:document href="{$pwd}Output/{$dtdName}/introduction.html"> 
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../../CSS/style.css"/>
      </head>
      <body>
	<h2>MN</h2>
	<h1>XHTML Reference</h1>
      </body>
    </html>
  </xsl:document>
-->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="xhtmlReference">
  <xsl:document href="{$pwd}Output/{$dtdName}/long.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../../CSS/style.css"/>
	<title>Zvon XHTML reference</title>
      </head>
      <body>
	<xsl:call-template name="index-header-special">
	  <xsl:with-param name="on">long</xsl:with-param>
	  <xsl:with-param name="id" select="$zvonItemid"/>
	  <xsl:with-param name="levelsBack" select="2"/>
	</xsl:call-template>
	<table>
	  <xsl:apply-templates select="element" mode="index"/>
	</table>
      </body>
    </html>
  </xsl:document>

  <xsl:apply-templates select="element" mode="description"/>

  <!-- short index generation   -->

  <xsl:call-template name="nextLetter">
    <xsl:with-param name="start" select="true()"/>
  </xsl:call-template>

  <xsl:call-template name="attributeIndex"/>

</xsl:template>

<xsl:template name="attributeIndex">
  <xsl:document href="{$pwd}Output/{$dtdName}/attrs.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../../CSS/style.css"/>
	<title>Zvon XHTML reference</title>
      </head>
      <body>

	<xsl:call-template name="index-header-special">
	  <xsl:with-param name="on">attrs</xsl:with-param>
	  <xsl:with-param name="id" select="$zvonItemid"/>
	  <xsl:with-param name="levelsBack" select="2"/>
	</xsl:call-template>

	<table>
	  <xsl:apply-templates select="/xhtmlReference/element/attribute" mode="attributeIndex">
	    <xsl:sort select="@name"/>
	  </xsl:apply-templates>
	</table>
      </body>
    </html>
  </xsl:document>

</xsl:template>

<xsl:template match="attribute" mode="attributeIndex">
  <xsl:variable name="firstID" select="generate-id(key('attribute',@name))" />
  
  <xsl:if test="generate-id() = $firstID">
    <tr>
      <td>
	<a target='mainWindow' href="./attr_{@name}.html" class="attribute"><xsl:value-of select="@name"/></a> 
      </td>
    </tr>
    <xsl:apply-templates select="." mode="description"/>
  </xsl:if>

</xsl:template>

<xsl:template match="element" mode="otherDTD">
  <!-- xsl:apply-templates select="dtd[not(@name=$dtdName)]" mode="printOtherDTD"/ -->
  <xsl:apply-templates select="dtd" mode="printOtherDTD"/>
</xsl:template>

<xsl:template match="dtd" mode="printOtherDTD">
  <xsl:choose>
    <xsl:when test="@name = $dtdName">
      <b>&gt;&gt; <xsl:value-of select="@name"/> &lt;&lt;</b>
      </xsl:when>
      <xsl:otherwise>
	<a href="../{@name}/el_{parent::element/@name}.html" class="naviBlack"><xsl:value-of select="@name"/></a>
	<xsl:text> </xsl:text>
      </xsl:otherwise>
    </xsl:choose>
    |
</xsl:template>

<xsl:template match="element" mode="description">
  <xsl:document href="{$pwd}Output/{$dtdName}/el_{@name}.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../../CSS/style.css"/>
	<title>Zvon XHTML reference</title>
      </head>
      <body>

	<xsl:call-template name="descriptionTop"/>

	<table class="hangingMenu" border="0" cellpadding="1" cellspacing="0" width="100%">
	  <tr>
	    <th class="descriptionMenu">&#160;&#160;<span class='descriptionMenu'>&#160;<xsl:value-of select='$dtdName'/>  XHTML&#160;</span>&#160;</th>
	    <td class="descriptionMenu">
	      <xsl:apply-templates select="key('otherDTD',$dtdName)/parent::element[@name=current()/@name]" mode="otherDTD"/>
	      <xsl:text>&#160;</xsl:text>
	      <xsl:if test="not($dtdName='Frameset')">
		<a class="descriptionMenu" href="../comparison.html">[Comparison]</a>
	      </xsl:if>
	    </td>
	  </tr>
	</table>

	<xsl:if test="@standard">
	  <br/>
	  <a target="mainWindow" class="standard" href="../../Standard/{@standard}">Go to Standard</a>
	</xsl:if>
	<br/>

	<table border="1" cellpadding="3">
	  <tr>
	    <td class="descLeft">Element:</td>
	    <td><a href="#" class="element"><xsl:value-of select="@name"/></a></td>
	  </tr>
	  <xsl:if test="attribute">
	    <tr>
	      <td class="descLeft">Attributes:</td>
	      <td> | <xsl:apply-templates select="attribute" mode="indexElement"/></td>
	    </tr>
	  </xsl:if>
	  <xsl:variable name="parent" select="key('parent',@name)"/>
	  <xsl:if test="$parent">
	    <tr>
	      <td class="descLeft">Parents:</td>
	      <td> | <xsl:apply-templates select="$parent" mode="link"/></td>
	    </tr>
	  </xsl:if>
	  <xsl:if test="child">
	    <tr>
	      <td class="descLeft">Children:</td>
	      <td> | <xsl:apply-templates select="child"/></td>
	    </tr>
	  </xsl:if>
	</table>
	<xsl:if test="key('exampleElement',@name)">
	  <xsl:apply-templates select="key('exampleElement',@name)/ancestor::example"/>
	</xsl:if>

      <xsl:call-template name="bottomLinks"/>

      </body>
    </html>
  </xsl:document>
</xsl:template>


<xsl:template match="child">
  <xsl:if test="not(preceding-sibling::child[. = current()])">
    <xsl:choose>
      <xsl:when test="not(.='PCDATA')">
	<a class="element" href="el_{.}.html"><xsl:value-of select="."/></a>
      </xsl:when>
      <xsl:otherwise>#PCDATA</xsl:otherwise>
    </xsl:choose>
    <xsl:text> | </xsl:text>
  </xsl:if>
</xsl:template>

<xsl:template match="element" mode="link">
  <xsl:choose>
    <xsl:when test="not(@name='PCDATA')">
      <a  class="element" href="el_{@name}.html"><xsl:value-of select="@name"/></a>
    </xsl:when>
    <xsl:otherwise>#PCDATA</xsl:otherwise>
  </xsl:choose>
      <xsl:text> | </xsl:text>
</xsl:template>

<xsl:template name="shortIndex">
  <xsl:param name="index"/>
  <xsl:param name="letter" select="substring($letters,1,1)"/>
  <xsl:param name="els"/>

  <xsl:document href="{$pwd}Output/{$dtdName}/short{$letter}.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../../CSS/style.css"/>
	<title>Zvon XHTML reference</title>
      </head>
      <body>


	<xsl:call-template name="index-header-special">
	  <xsl:with-param name="on">short</xsl:with-param>
	  <xsl:with-param name="id" select="$zvonItemid"/>
	  <xsl:with-param name="levelsBack" select="2"/>
	  <xsl:with-param name="letter" select="$letter"/>
	</xsl:call-template>

	<table><tr><td>
	  <xsl:call-template  name="shortHeader">
	    <xsl:with-param name="leadingLetter" select="$letter"/>
	  </xsl:call-template>
	</td></tr></table>

	<table>
	  <xsl:apply-templates select="$els" mode="index"/>
	  <xsl:call-template name="nextLetter">
	    <xsl:with-param name="index" select="$index"/>
	    <xsl:with-param name="count" select='count($els)'/>
	  </xsl:call-template>
	</table>
      </body>
    </html>
  </xsl:document>
</xsl:template>

<xsl:template name="nextLetter">
  <xsl:param name="start" select="false()"/>
  <xsl:param name="count" select="0"/>
  <xsl:param name="index" select="0"/>
  <xsl:variable name="newIndex" select="$index + 1"/>
  <xsl:variable name="letter" select="substring($letters,$newIndex,1)"/>
  <xsl:variable name="els" select="element[substring(@name,1,1)=$letter]"/>
  <xsl:variable name="newCount" select="count($els) + $count"/>
  
  <xsl:choose>
    <xsl:when test="$letter=''"/>
    <xsl:when test="$start or ($newCount &gt; $maxShortItems)">
      <xsl:call-template name="shortIndex">
	<xsl:with-param name="letter" select="$letter"/>
	<xsl:with-param name="index" select="$newIndex"/>
	<xsl:with-param name="els" select="$els"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates select="$els" mode="index"/>
      <xsl:call-template name="nextLetter">
	<xsl:with-param name="count" select="$newCount"/>
	<xsl:with-param name="index" select="$newIndex"/>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="element" mode="index">
  <xsl:if test="not(@name='PCDATA')">
    <tr>
      <td>
	<a  class="element" href="el_{@name}.html" target="mainWindow"><xsl:value-of select="@name"/></a> 
	<xsl:text> </xsl:text>
	<xsl:if test="@standard">[<a target="mainWindow" class="standard" href="../../Standard/{@standard}">st</a>]</xsl:if>
      </td>
    </tr>
    <xsl:apply-templates select="." mode="description"/>
  </xsl:if>
</xsl:template>

<xsl:template name="shortHeader">
  <xsl:param name="count" select="0"/>
  <xsl:param name="index"/>
  <xsl:param name="oldLink">a</xsl:param>
  <xsl:param name="headerIndex" select="1"/>
  <xsl:param name="leadingLetter"/>

  <xsl:variable name="letter" select="substring($letters,$headerIndex,1)"/>
  <xsl:variable name="els" select="element[substring(@name,1,1)=$letter]"/>

  <xsl:variable name="newCount" select="count($els) + $count"/>

  <xsl:variable name="link">
    <xsl:choose>
      <xsl:when test="$newCount &gt; $maxShortItems"><xsl:value-of select="$letter"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="$oldLink"/></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  
  <xsl:variable name="newCountFinal">
    <xsl:choose>
      <xsl:when test='$link = $oldLink'><xsl:value-of select="$newCount"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="count($els)"/></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>


  <xsl:if test="$letter">
    <xsl:choose>
      <xsl:when test="$leadingLetter = $link">
	<b><xsl:value-of select="$letter"/></b>
      </xsl:when>
      <xsl:otherwise>
	<a class="shortLetters" href="./short{$link}.html"><xsl:value-of select="$letter"/></a>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text> - </xsl:text>

  
    <xsl:call-template name="shortHeader">
      <xsl:with-param name="headerIndex" select="$headerIndex + 1"/>
      <xsl:with-param name="oldLink" select="$link"/>
      <xsl:with-param name="count" select="$newCountFinal"/>
      <xsl:with-param name="leadingLetter" select="$leadingLetter"/>
    </xsl:call-template>
  </xsl:if>
</xsl:template>

<xsl:template match="attribute" mode="index">
  <tr>
    <td>
      <a class="attribute" href="el_{parent::element/@name}_{@name}.html" target="mainWindow"><xsl:value-of select="@name"/></a>
      <xsl:text> [ </xsl:text>
      <a class="element" href="el_{parent::element/@name}.html" target="mainWindow"><xsl:value-of select="parent::element/@name"/></a>
      <xsl:text> ] </xsl:text>
    </td>
  </tr>
  <xsl:apply-templates select="." mode="description"/>
</xsl:template>


<xsl:template match="attribute" mode="indexElement">
  <xsl:variable name="required">
    <xsl:if test="@occurence='#REQUIRED'">Required</xsl:if>
  </xsl:variable>
  <a href="./attr_{@name}.html" class="attribute{$required}"><xsl:value-of select="@name"/></a>
  <xsl:text> | </xsl:text>
</xsl:template>


<xsl:template match="attribute" mode="itemDescription">
	    <tr>
	      <td class="descLeft"> Parent: </td>
	      <td><a href="el_{parent::element/@name}.html" class="element"><xsl:value-of select="parent::element/@name"/></a> [<a class="standard" href="../../Standard/{@standard}">Go to standard</a>]</td>
	    </tr>
	    <tr>
	      <td class="descLeft"> Values: </td>
	      <td><xsl:value-of select="@value"/></td>
	    </tr>
</xsl:template>


<xsl:template match="attribute" mode="description">
  <xsl:document href="{$pwd}Output/{$dtdName}/attr_{@name}.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../../CSS/style.css"/>
	<title>Zvon XHTML reference</title>
      </head>
      <body>

	<xsl:call-template name="descriptionTop"/>

	<table width='100%' cellspacing="0">
	  <tr>
	    <th class="descriptionMenu">&#160;&#160;&#160;<span class='descriptionMenu'>&#160;<xsl:value-of select='$dtdName'/>  XHTML&#160;</span>&#160;&#160; </th>
	  </tr>
	</table>
	<br/>
	<table cellpadding='3' border='1'>
	  <tr>
	    <td class="descLeft"> Attribute: </td>
	    <td>
	      <a href="#" class="attribute"><xsl:value-of select="@name"/></a>
	    </td>
	  </tr>

	  <xsl:apply-templates select="key('attribute',@name)[@standard]" mode="itemDescription">
	    <xsl:sort select="parent::element/@name"/>
	  </xsl:apply-templates>

	</table>

      <xsl:call-template name="bottomLinks"/>

      </body>
    </html>
  </xsl:document>
</xsl:template>

<xsl:template name="descriptionTop">
  <xsl:call-template name="share_descriptionTop">
    <xsl:with-param name="id" select="$zvonItemid"/>
    <xsl:with-param name="levelsBack" select="2"/>
  </xsl:call-template>
</xsl:template>






<xsl:template name="header_common">
  <xsl:param name="url"/>
  <xsl:param name="sectionId"/>
  <xsl:param name="break">no</xsl:param>
  <xsl:variable name="field">
    <items xmlns="">
      <a id="Strict" class="naviBlack" href="../Strict/{$url}.html">Strict</a>
      <a id="Transitional" class="naviBlack" href="../Transitional/{$url}.html">Transitional</a>
      <a id="Frameset" class="naviBlack" href="../Frameset/{$url}.html">Frameset</a>
    </items>
  </xsl:variable>

  <table class="hangingMenu" border="0" cellpadding="1" cellspacing="0" width="100%">
    <tr>
      <td>
	<xsl:if test="$break = 'yes'"><br/></xsl:if>
	<xsl:for-each select="$field/items/a">
	  <xsl:choose>
	    <xsl:when test="@id = $sectionId">
	      <b>>>&#160;<xsl:value-of select="."/>&#160;&lt;&lt;</b>
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:copy-of select="."/>
	    </xsl:otherwise>
	  </xsl:choose>
	  <xsl:if test="not(position() = last())"> | </xsl:if>
	</xsl:for-each>
      </td>
    </tr>
  </table>
</xsl:template>



<xsl:template name="index-header-special">
  <xsl:param name="id"/>
  <xsl:param name="on"/>
  <xsl:param name="levelsBack">2</xsl:param>
  <xsl:param name="letter"/>

  <xsl:message>
    index-header::id: <xsl:value-of select="$id"/>
  </xsl:message>

  <xsl:call-template name="tinyTopMenu">
    <xsl:with-param name="id" select="$id"/>
    <xsl:with-param name="levelsBack" select="$levelsBack"/>
  </xsl:call-template>

  <xsl:call-template name="topMenubar">
    <xsl:with-param name="letter" select="$letter"/>
  </xsl:call-template>

  <xsl:if test="$menu">
    <table width="100%">
      <tr>
	<td class="descriptionMenu">
	  <ul>
	    <xsl:apply-templates select="$menu/groups/*" mode="indexMenu">
	      <xsl:with-param name="id" select="$on"/>
	  </xsl:apply-templates>
	</ul>
      </td>
    </tr>
  </table>
  <hr />
</xsl:if>
</xsl:template>


<xsl:template name="topMenubar">
  <xsl:param name="letter"/>
  <xsl:variable name="url">
    <xsl:choose>
      <xsl:when test="$letter"><xsl:value-of select="concat('short','a')"/></xsl:when>
      <xsl:otherwise>long</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:call-template name="header_common">
    <xsl:with-param name="sectionId" select="$dtdName"/>
    <xsl:with-param name="url" select="$url"/>
  </xsl:call-template>
</xsl:template>


</xsl:stylesheet>




